@@ -2,11 +2,10 @@ package Log::Dispatch::Email::Mailer;
 # ABSTRACT: Log::Dispatch::Email subclass that sends mail using Email::Mailer
 
 use 5.014;
-use exact;
-use base 'Log::Dispatch::Email';
-use Email::Mailer 1.09;
+use exact 'Log::Dispatch::Email';
+use Email::Mailer;
 
-our $VERSION = '1.10'; # VERSION
+our $VERSION = '1.11'; # VERSION
 
 sub _params {
     my %params = @_;
@@ -66,7 +65,7 @@ Log::Dispatch::Email::Mailer - Log::Dispatch::Email subclass that sends mail usi
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =for markdown [![test](https://github.com/gryphonshafer/Log-Dispatch-Email-Mailer/workflows/test/badge.svg)](https://github.com/gryphonshafer/Log-Dispatch-Email-Mailer/actions?query=workflow%3Atest)
 [![codecov](https://codecov.io/gh/gryphonshafer/Log-Dispatch-Email-Mailer/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/Log-Dispatch-Email-Mailer)
